# planqk-commons

Set of common utilities and classes to boost development of quantum computing applications using the PLANQK Platform.

## Development

### Setup

```bash
conda env create -f environment.yml
conda activate planqk-commons
```

### Run tests

```bash
pytest
```

## License

Apache-2.0 | Copyright 2024 Kipu Quantum GmbH
